//---------------------------------------------------------------------------
// Copyright (C) 1998 Dallas Semiconductor Corporation, All Rights Reserved.
// 
// Permission is hereby granted, free of charge, to any person obtaining a 
// copy of this software and associated documentation files (the "Software"), 
// to deal in the Software without restriction, including without limitation 
// the rights to use, copy, modify, merge, publish, distribute, sublicense, 
// and/or sell copies of the Software, and to permit persons to whom the 
// Software is furnished to do so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included 
// in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS 
// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF 
// MERCHANTABILITY,  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. 
// IN NO EVENT SHALL DALLAS SEMICONDUCTOR BE LIABLE FOR ANY CLAIM, DAMAGES 
// OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, 
// ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR 
// OTHER DEALINGS IN THE SOFTWARE.
// 
// Except as contained in this notice, the name of Dallas Semiconductor 
// shall not be used except as stated in the Dallas Semiconductor 
// Branding Policy. 
//---------------------------------------------------------------------------
//
//  RPTEVENT.C - MicroLan repeater event management processing. These
//               functions should be changed to refect the actual method
//               used for the repeater to send and receive packets.
//
//  Version: 1.00
//

// includes
#include "mlanpkt.h"

// external functions 
extern int MLanProcessPacket(void);
extern uchar SingleResult(uchar, uchar); 

// local functions
void MLanInboundArriveEvent(uchar *);
void MLanOutboundSendEvent(uchar *);

// host's buffer to hold received data from the repeater
extern uchar host_receive[];
extern uchar host_got_packet;

// flag to indicated processing inbound
static int processing_inbound = FALSE;
// busy outbound message when processing commands
static uchar busy_outbound[] = { 0x02, CMD_ERROR, RET_BUSY };

//----------------------------------------------------------------------
// Simulated Event created when an inbound packet arrives
//
void MLanInboundArriveEvent(uchar *inbound_buffer)
{
   int i;

   // process the inbound buffer if not currently processing
   if (!processing_inbound)
   {
      // currently processing inbound buffer
      processing_inbound = TRUE;
 
      // make sure length is non-zero
      if (inbound_buffer[0])
      {
         // check if inbound is too big
         if (inbound_buffer[0] <= inbound_max[0])
         {
            // is first command CMD_GETBUF
            if (inbound_buffer[1] != CMD_GETBUF)
            {
               // if last command was CMD_GETBUF then reset
               if (last_cmd == CMD_GETBUF)
                  outbound[0] = 0;
      
               // check if last command return was non-halt
               if ((last_cmd_return == RET_SUCCESS) ||
                   (last_cmd_return == RET_END_SEARCH))
               {  
                  // copy the inbound buffer into the repeater's
                  for (i = 0; i <= inbound_buffer[0]; i++)
                     inbound[i] = inbound_buffer[i];  

                  // process the inbound packet that just arrived
                  MLanProcessPacket();
               }
            }
            // first command is CMD_GETBUF
            else
            {
               last_cmd = CMD_GETBUF;
               last_cmd_return = RET_SUCCESS;
               MLanOutboundSendEvent(outbound);
            }
         }
         // too big
         else
            SingleResult(CMD_ERROR, RET_READ_ONLY);                        
      }

      // finished processing inbound message
      processing_inbound = FALSE;
   }
   // currently busy so reply with the busy message
   else  
      MLanOutboundSendEvent(busy_outbound);
}

//----------------------------------------------------------------------
// Simulated Event that would send an outbound packet to the host
//
void MLanOutboundSendEvent(uchar *outbound_buffer)
{
   int i;

   // copy the buffer to send into the host receive
   for (i = 0; i <= outbound_buffer[0]; i++)
      host_receive[i] = outbound_buffer[i];  

   // indicate that the packet was received by host
   host_got_packet = TRUE;
}


