//---------------------------------------------------------------------------
// Copyright (C) 1998 Dallas Semiconductor Corporation, All Rights Reserved.
// 
// Permission is hereby granted, free of charge, to any person obtaining a 
// copy of this software and associated documentation files (the "Software"), 
// to deal in the Software without restriction, including without limitation 
// the rights to use, copy, modify, merge, publish, distribute, sublicense, 
// and/or sell copies of the Software, and to permit persons to whom the 
// Software is furnished to do so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included 
// in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS 
// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF 
// MERCHANTABILITY,  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. 
// IN NO EVENT SHALL DALLAS SEMICONDUCTOR BE LIABLE FOR ANY CLAIM, DAMAGES 
// OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, 
// ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR 
// OTHER DEALINGS IN THE SOFTWARE.
// 
// Except as contained in this notice, the name of Dallas Semiconductor 
// shall not be used except as stated in the Dallas Semiconductor 
// Branding Policy. 
//---------------------------------------------------------------------------
//
//  HostPkt.C - Packet receive and send functions for the host.  These
//              functions should be changed to refect the actual method
//              and protocal used to get the frame to and from the 
//              MicroLan repeater.
//
//  Version: 1.00
//

// include for testing
#include "mlanpkt.h"

// buffer to hold received data from the repeater
uchar host_receive[MAX_OUTFRAME+1];
// flag to indicate a packet was received
int host_got_packet = FALSE;

// external functions for testing
extern void MLanInboundArriveEvent(uchar *);
extern int PrintPacket(uchar *, int);

// exportable functions
int MLanHostPacketReceive(uchar *);
void MLanHostPacketSend(uchar *);

//--------------------------------------------------------------------------
// Receive a packet frame from the repeater.
//
int MLanHostPacketReceive(uchar *receive_packet)
{
   int i;

   // add platform/protocol specific code here
   
   // check if a packet was received
   if (host_got_packet)
   {
      // indicate the packet was read by host
      host_got_packet = FALSE;
      // for demonstration purpose we will just copy what
      // the repeater has placed into our buffer
      for (i = 0; i <= host_receive[0]; i++) 
         receive_packet[i] = host_receive[i];
   }
   else
      receive_packet[0] = 0;

   // print the outbound packet
   PrintPacket(receive_packet, OUTBOUND);

   // return the length in bytes of the packet including length byte
   return receive_packet[0] + 1;
}


//--------------------------------------------------------------------------
// Send a packet frame to the repeater
//
void MLanHostPacketSend(uchar *send_packet)
{
   // add platform/protocol specific code here
   
   // print the inbound packet
   PrintPacket(send_packet, INBOUND);

   // for demonstration puposes, create an event in the repeater to signal
   // arrival of an inbound packet
   MLanInboundArriveEvent(send_packet);
}

